#!/usr/bin/env node
const chalk = require('chalk')

const files = require('./lib/files')
const inquirer = require('./lib/inquirer')
const github = require('./lib/github')
const repo = require('./lib/repo')

// 判断当前目录是否已经是一个 git 目录
if (files.directoryExists('.git')) {
  console.log(chalk.red('Current Folder is already a git repository!'))
  process.exit()
}

// 获取 github 的 token 信息
const getGithubToken = async () => {
  let token = github.getStoredGithubToken()
  if (token) {
    return token
  }
  await github.setGithubCredentials()
  token = await github.registerNewToken()
  return token
}

const run = async () => {
  try {
    const token = await getGithubToken()
    // github 授权
    github.githubAuth(token)
    // 创建并且返回创建的 github 库的 url 信息
    const url = await repo.createRemoteRepo()
    // 创建 .gitignore 文件
    await repo.createGitignore()
    // 初始化项目各类初始化文件，并且 push 到远程 master
    const done = await repo.setupRepo(url)
    if (done) {
      console.log(chalk.green('All done!'))
    }
  } catch (err) {
    if (err) {
      switch (err.code) {
        case 401:
          console.log(chalk.red('Couldn\'t log you in. Please provide correct credentials/token.'))
          break
        case 422:
          console.log(chalk.red('There already exists a remote repository with the same name'))
          break
        default:
          console.log(err)
      }
    }
  }
}
try {
  run()
} catch (err) {
  console.error(err)
}
