const _ = require('lodash')
const chalk = require('chalk')
const Configstore = require('configstore')
const CLI = require('clui')
const octokit = require('@octokit/rest')()
const inquirer = require('./inquirer')
const pkg = require('../package')

const Spinner = CLI.Spinner
const conf = new Configstore(pkg.name)

module.exports = {
  getInstance: () => {
    return octokit
  },

  getStoredGithubToken: () => {
    return conf.get('github.token')
  },

  setGithubCredentials: async () => {
    const credentials = await inquirer.askGithubCredentials()
    octokit.authenticate(
      Object.assign({ type: 'basic' }, credentials)
    )
  },

  registerNewToken: async () => {
    const status = new Spinner('Authenticating you, please wait...\n')
    status.start()

    try {
      const response = await octokit.authorization.create({
        scopes: ['user', 'public_repo', 'repo', 'repo:status'],
        note: 'ginits, the command-line tool for initalizing Git repos'
      })
      const token = response.data.token
      if (token) {
        conf.set('github.token', token)
        return token
      } else {
        throw new Error('Missing Token', 'GitHub token was not found in the response')
      }
    } catch (err) {
      throw err
    } finally {
      status.stop()
    }
  },

  githubAuth: (token) => {
    octokit.authenticate({
      type: 'oauth',
      token: token
    })
  },

  getStoredGithubToken: () => {
    return conf.get('github.token')
  }
}